# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="1.0.0"></a>
## 1.0.0 (2019-01-17)

* feat: Add CJS module ([fbba6fa](https://github.com/znck/vue-runtime-helpers/commit/fbba6fa))
* feat: Publish ES6 module ([4b1caaa](https://github.com/znck/vue-runtime-helpers/commit/4b1caaa))
* test: Runtime helper functions ([dd2135f](https://github.com/znck/vue-runtime-helpers/commit/dd2135f))


### BREAKING CHANGE

* `normalize-component.js` moved to
`dist/normalize-component.js`


<a name="0.1.2"></a>
## [0.1.2](https://github.com/znck/vue-runtime-helpers/compare/v0.1.1...v0.1.2) (2018-05-13)
